export default {
    "message": "Await expression cannot be a default value",
    "column": 9,
    "index": 32,
    "lineNumber": 2
}